caellion-python-commons: caellion.pycommons.stringutil.unixpassword.DuplicateFieldException Class Reference

caellion-python-commons

caellion.pycommons.stringutil.unixpassword.DuplicateFieldException Class Reference

This exception is raised when more than exactly one instance of a given field is contained within field list. More...

Inheritance diagram for caellion.pycommons.stringutil.unixpassword.DuplicateFieldException:

## Detailed Description

This exception is raised when more than exactly one instance of a given field is contained within field list.

Definition at line 6 of file unixpassword.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/stringutil/unixpassword.py